src/hotspot/share/runtime/mutexLocker.hpp
changeset 51520 ef7852ece52b
parent 51511 eb8d5aeabab3
child 51548 35a6956f4243
--- a/src/hotspot/share/runtime/mutexLocker.hpp	Mon Aug 20 12:08:07 2018 +0200
+++ b/src/hotspot/share/runtime/mutexLocker.hpp	Fri Aug 24 09:12:51 2018 -0500
@@ -57,7 +57,7 @@
 extern Mutex*   AdapterHandlerLibrary_lock;      // a lock on the AdapterHandlerLibrary
 extern Mutex*   SignatureHandlerLibrary_lock;    // a lock on the SignatureHandlerLibrary
 extern Mutex*   VtableStubs_lock;                // a lock on the VtableStubs
-extern Mutex*   SymbolTable_lock;                // a lock on the symbol table
+extern Mutex*   SymbolArena_lock;                // a lock on the symbol table arena
 extern Mutex*   StringTable_lock;                // a lock on the interned string table
 extern Monitor* StringDedupQueue_lock;           // a lock on the string deduplication queue
 extern Mutex*   StringDedupTable_lock;           // a lock on the string deduplication table